require 'spec_helper'
require 's3rsync/sync'

include Helpers

describe S3Rsync::Sync do
  context 'sync is successfull' do
    let(:opt) {
      {
        'path'        => '/parent_test_dir/test_dir',
        's3-prefix'   => 's3rsync',
        'config-path' => 'test_json_conf_path.json',
        'dry-run'     => false,
        'make-public' => false,
        'enable-lock' => false,
      }
    }
    
    let(:json_conf) {
      {
        'env.static.s3.bucket'      => 'test-bucket',
        'env.static.s3.key.user'    => 'test_access_key',
        'env.static.s3.key.secret'  => 'test_secret_key',
      } 
    }
    
    let(:s3_conf_path) { opt['config-path'].sub('.json', '_s3rsync.conf') }
    let(:base_sync_path) { opt['path'].split('/').last }
    let(:common_args) { ['-c', s3_conf_path].join(' ') }
    
    before do
      allow(File).to receive(:read).and_return(nil)
      allow(File).to receive(:read).with(opt['config-path']).and_return(json_conf.to_json)
      allow(Dir).to receive(:exists?).and_return(nil)
      allow(Dir).to receive(:exists?).with(opt['path']).and_return(true)
      allow_any_instance_of(S3Rsync::Sync).to receive(:pass_cli).and_return(nil)
    end
    
    after do
      #
    end
    
    before(:each) do
      #Helpers::pre_run_helper
    end
    
    after(:each) do
      File.unlink s3_conf_path
    end
    
    it "uploads dir" do
      cmd = "s3cmd #{common_args} sync #{opt['path']}/ s3://#{json_conf['env.static.s3.bucket']}/#{opt['s3-prefix']}#{opt['path']}/"
      allow_any_instance_of(S3Rsync::Sync).to receive(:pass_cli).with(cmd).and_return('Success')
      
      sync = S3Rsync::Sync.new(opt)
      expect(sync.run(:upload)).to eq 0
    end
    
    it "downloads dir" do
      cmd = "s3cmd #{common_args} sync s3://#{json_conf['env.static.s3.bucket']}/#{opt['s3-prefix']}#{opt['path']}/ #{opt['path']}/"
      allow_any_instance_of(S3Rsync::Sync).to receive(:pass_cli).with(cmd).and_return('Success')
      
      sync = S3Rsync::Sync.new(opt)
      expect(sync.run(:download)).to eq 0
    end
  end
end
